#
# spec file for package kdoctools
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5DocTools5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kdoctools
Version:        5.116.0
Release:        1.1
Summary:        Tools to create documentation from DocBook
License:        LGPL-2.1-or-later AND MIT
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
# PATCH-FEATURE-OPENSUSE
Patch1:         0001-Also-return-KDE4-docs-in-documentationDirs.patch
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  perl-URI
BuildRequires:  cmake(KF5Archive) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
# The XSL templates reference files in here
Requires:       docbook-xsl-stylesheets

%description
Provides tools to generate documentation in various format from DocBook files.

%package -n %{lname}
Summary:        Library to create documentation from DocBook
%requires_ge    libQt5Core5
Recommends:     %{name} = %{version}

%description -n %{lname}
Provides tools to generate documentation in various format from DocBook files.

%package devel
Summary:        Build environment for kdoctools
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Requires:       docbook-xsl-stylesheets
Requires:       libxslt-devel
Requires:       cmake(Qt5Core) >= %{qt5_version}
Provides:       %{name}-devel-static = %{version}

%description devel
Provides tools to generate documentation in various format from DocBook files.
Development files.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

%find_lang %{name} --with-man --all-name

%ldconfig_scriptlets -n %{lname}

%files lang -f %{name}.lang

%files
%{_kf5_htmldir}/*/
%{_kf5_datadir}/kdoctools/
%{_kf5_bindir}/meinproc5
%{_kf5_bindir}/checkXML5
%doc %lang(en) %{_kf5_mandir}/*/meinproc5.*
%doc %lang(en) %{_kf5_mandir}/*/checkXML5.*
%doc %lang(en) %{_kf5_mandir}/*/kf5options.*
%doc %lang(en) %{_kf5_mandir}/*/qt5options.*

%files -n %{lname}
%license LICENSES/*
%doc README*
%{_kf5_libdir}/libKF5DocTools.so.*

%files devel
%{_kf5_includedir}/KDocTools/
%{_kf5_libdir}/cmake/KF5DocTools/
%{_libdir}/libKF5DocTools.so

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- Changes since 5.112.0:
  * Fix build with libxml2 v2.12
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- No code change since 5.108.0
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
  * doc: use a more generic Frameworks entity in the example
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- Changes since 5.106.0:
  * Add Arabic Support
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- No code change since 5.105.0
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * kdoctools_install: fix doc detection in path with special chars
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Install version header
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- No code change since 5.102.0
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Adding myself to the contributor list
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- No code change since 5.100.0
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- No code change since 5.99.0
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Add Qt6 windows CI support
  * .gitlab-ci.yml: enable static builds
  * Spelling: sync the Valencian language with the latest changes into GUI
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Add Han Young to the contributors list
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * catalog: Avoid needlessly copying a list to be returned.
  * meinproc: Simplify loop building param list for libxml.
  * meinproc: Fix usage of QString reference to temporary.
  * meinproc: Remove old comment from porting.
  * meinproc: Remove dead entry parsing code.
  * allow build with nix package manager
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * update French user.entities
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * add Windows CI
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Require unittests to pass for CI jobs to pass
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * [ca@valencia] Add Catalan (Valencian) Language
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Check executables exist in PATH before passing them to QProcess
  * Fix install test with Qt6
  * Don't hardcode "kf5" for the catalog search path
  * Add CI qt6 support
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Remove the usage of QTextCodec (and thus Qt6Core5Compat) for Qt6
  * Don't compare signed with unsigned int
  * Change the build system to enable building with Qt 6
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * [ca]: Improve all references to 'licensed under'
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Add FreeBSD CI
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * Move ksnake to deprecated and add ksnakeduel entity
  * Add an entity for Kigo
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Add a max width to the content
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Add entity for krename
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Bump required CMake version to 3.16
  * Hook up customizations for sq (Albanian) and de-duplicate
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- No code change since 5.81.0
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- No code change since 5.80.0
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- No code change since 5.79.0
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * A tag fixed
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Add an entity for MathML acronym
  * Mispelled to previous commit
  * Change 'Naval Battle' to 'KNavalBattel' to meet legal matters
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- No code change since 5.76.0
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Fix xml formatting in contributor.entities.
  * Update contributor.entities for KMail documentation Chapter 4.
  * Korean update: fix typo on entity
  * Various fixes
  * Documentation fixes
  * Korean update
  * Korean update: reformat HTML files of GPL, FDL and add LGPL
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Fix an entity
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Remove obsolete COPYING files
  * Update general.entities -- add locally defined entities in old KMail documentation to global list.
  * Update contributor.entities
  * Use placeholder markers
  * Add license texts according to REUSE specification
  * Convert copyright statements to SPDX expressions
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Use consistent style for FDL notice (kde#423211)
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- No code change since 5.70.0
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- No code change since 5.69.0
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Use bold italic at 100%% for sect4 titles, and bold 100%% for sect5 titles (kde#419256)
  * Update the list of the Italian entities
  * Use the same style for informaltable as for table (kde#418696)
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- No code change since 5.66.0
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Port endl to "\n", endl in qt5.15 is namespaced.
  * [KDocTools] Port QRegExp to QRegularExpression
  * Minor update of Ukrainian translation
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Catalan Works: Add missing entitie
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * man: use <arg> instead of <group>
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Port from QString sprintf to arg
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * KF5DocToolsMacros.cmake: Use non-deprecated KDEInstallDirs variables (kde#410998)
  * Remove unused includes
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- No code change since 5.60.0
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Update pt-BR user.entities
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- No code changes since 5.58.0
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- No code changes since 5.57.0
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Update Ukrainian translation
  * Catalan updates
  * it entities: update URLs to use https
  * Update URLs to use https
  * Use Indonesian translation
  * Update design to look more similar to kde.org
  * Add necessary files to use native Indonesian language for all Indonesian docs.
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * It compiles find with QT5.13 without deprecated method
  * Make it compiles without foreach
  * Port cross-compilation support to KF5_HOST_TOOLING
  * Only report DocBookXML as found if it was actually found
  * Update Spanish entities
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * No code changes since 5.54.0
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * No code changes since 5.53.0
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summaries.
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * Fix running kdoctools-install autotest without kdoctools installed
  * It builds without deprecated method
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Fix autotests with -DBUILD_QCH:BOOL=TRUE
  * API dox: fix typo
  * API dox: add minimal docs to KDocTools namespace, so doxygen covers it
  * Create a QCH file with the API dox, optionally, using ECMAddQCH
  * Wait for docbookl10nhelper to be built before building our own manpages
  * Use specified Perl interpreter instead of relying on PATH
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * No code changes since 5.50.0
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * add acronym ASCII to general.entities
  * add JSON to general.entities
  * Let test.cmake find the files where they were installed
  * Let meinproc5 be more verbose in 'install' auto test
  * Let 'install' autotest build in verbose mode to see KDE CI build issues
  * Fix KDE CI compile issue
  * In kdoctools_install test use absolute pathes to find installed files
  * Convert manual install test to an autotest
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * None
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Update the list of Ukrainian entities
  * add entity OSD to general.entites > > 10 hits in trunk l10n-kf5/documentation Differential Revision: https://phabricator.kde.org/D13024
  * Add entities CIFS, NFS, Samba, SMB to general.entities
  * Add Falkon, Kirigami, macOS, Solid, USB, Wayland, X11, SDDM to general entities
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Use const'ref
  * Translate to Catalan gpl-notice.docbook and lgpl-notice.docbook
  * customization/ru: Translate gpl-notice.docbook and lgpl-notice.docbook
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Add entities for Elisa, Markdown, KParts, DOT, SVG to general.entities
  * customization/ru: Fix translation of underCCBYSA4.docbook and underFDL.docbook
  * Fix duplicate lgpl-notice/gpl-notice/fdl-notice
  * customization/ru: Translate fdl-notice.docbook
  * change spelling of kwave requested by the maintainer
  * Remove not necessary QtCore and co
- Don't mark /usr/share/doc/HTML*/kdoctools5-common as %%doc,
  they're files needed to display help properly (boo#1088562)
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * customization/entities/contributor.entities - fix typo . missing '>'
  * rename KDE-Partitionsmanager to Partitionsverwaltung, KDE does not make any sense here
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * add entity for Michael Pyne
  * Remove obsolete reviewboardrc file
  * add entities for Martin Koller to contributor.entities
  * fix debian entry
  * add entity Debian to general.entities
  * add entity kbackup, it was imported
  * add entity latex, we have already 7 entities in different index.docbooks in kf5
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Update Brasilian Portuguese translation
  * Update Russian translation
  * Update Russian translation
  * Update customization/xsl/ru.xml (nav-home was missing)
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Update Catalan translation
  * Update Ukrainian translation
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * None
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * CMake: Fix target name shortening when build dir has special characters (kde#377573)
  * Add CC BY-SA 4.0 International and set it as default
* Sun Aug 20 2017 fabian@ritter-vogt.de
- Require docbook-xsl-stylesheets, the included XSL files reference
  docbook XSL files
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Move meinproc5's man page from section 8 to section 1
* Tue Jul 25 2017 fabian@ritter-vogt.de
- Add patch to also return the KDE4 documentation directories:
  * 0001-Also-return-KDE4-docs-in-documentationDirs.patch
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * New function to retrieve the documentation directories
  * Fix a few MSVC warnings
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * add entity kmplayer
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Workaround for MSVC and catalog loading
  * Solve a visibility conflict for meinproc5 (kde#379142)
  * Quote few other variables with path (avoid issues with spaces)
  * Quote few variables with path (avoid issues with spaces)
  * Temporarily disable the local doc on Windows
  * FindDocBookXML4.cmake, FindDocBookXSL.cmake - search in homebrew installations
- Use %%find_lang --all-name --with-man for .lang filelist
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Upgrade KF5 version to 5.33.0.
  * meinproc5: link to the files, not to the library
* Mon Mar 20 2017 lbeltrame@kde.org
- Add a new subpackage to track the new shared library provided
  by doctools
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * meinproc5: link to the files, not to the library
  * Commit translations from l10n-kf5
  * Remove the KF5::XsltKde static library
  * Port to categorized logging and clean includes
  * Export a proper shared library for KDocTools
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Add function to extract a single file
  * Revert "Port to categorized logging and clean includes"
  * Port to categorized logging and clean includes
  * Fail the build early if xmllint is not available
  * Upgrade KF5 version to 5.32.0.
  * add entity for application Kst
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Fix 'checkXML5 generates html files in workdir for
    valid docbooks' (kde#371987)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Fix 'checkXML5 prints generated html to stdout for valid docbooks'
    (kde#369415)
  * Fix bug not been able to run native tools in package using cross
    compiled kdoctools
  * Setup targets for cross compiling running kdoctools from
    other packages
  * Add cross compiling support for docbookl10nhelper
  * Add cross compile support for meinproc5
  * Convert checkxml5 into a qt executable for cross platform support
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Add paths for config, cache + data to general.entities
  * Made up-to-date with the English version
  * Add Space and Meta key entities to
    src/customization/en/user.entities
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Allow KDocTools to always locate at least its own installed stuff
  * Use CMAKE_INSTALL_DATAROOTDIR to look for docbook instead of share
  * Update qt5options manpage docbook to qt 5.4
  * Update kf5options manpage docbook
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Add commonly used entities for keys to en/user.entities
  * Update man-docbook template
  * Update book template + man template + add arcticle template
  * Call kdoctools_create_handbook only for index.docbook
    (kde#357428)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Added entity applications
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Use unicode characters for callouts
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Update pt_BR entities
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Sync Catalan user.entities with English (en) version.
  * Add entities for sebas and plasma-pa
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Change sentence about reporting bugs, ack'ed by dfaure
  * Adapt german user.entities to en/user.entities
  * Update general.entities: change markup for frameworks + plasma
    from application to productname
  * Update en/user.entities
  * Update book and man page templates
  * Use CMAKE_MODULE_PATH in cmake_install.cmake
  * Update general.entities
  * Search for required perl modules.
  * Namespace a helper macro in the installed macros file.
  * Adapted key name tranlations to standard tranlations provided
    by Termcat
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Update K5 docbook templates
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Update translations
  * Update customization/ru
  * Fix entities with wrong links
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Fix the build on MacOSX when using Homebrew
  * Better styling of media objects (images, ...) in documentation
  * Encode invalid chars in paths used in XML DTDs, avoiding errors
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
- Drop karchive-devel from devel package requires
- Added perl-URI buildrequires
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Thu Oct 16 2014 vpelcak@suse.com
- moving meinproc and checkXML5 and manpages to main package.
  Reason is to make these tools available to translators, who use
  automated tools for translation handling (pology) without need
  to install devel package which brings many otherwise unnecessary
  dependencies
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
- Added ki18n-devel for new lang subpackage
- Let main package Recommend lang package
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Fri Feb 21 2014 hrvoje.senjan@gmail.com
- Mark license as LGPL-2.1+ and MIT
- Include license as %%doc
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kdoctools package
